@@ -201,8 +201,8 @@ class MainArea(param.Parameterized):
                                        #              show_name=False, widgets={'gen_btn': {'button_type': 'primary'}}),
                                        #     sizing_mode='stretch_width', margin=(50, 0, 0, 0)
                                        # ),
-                                       self.structure)),
-            ('Preprocess Data', self.rename_files),
+                                       )),
+            ('Preprocess Data', pn.Column(PREPROCESS, self.rename_files)),
             ('View Results', ViewResults().view()),
             ('User Guide', UserGuide().view()),
             dynamic=True, active=0
@@ -374,3 +374,8 @@ Click on **Generate Files** button to physically save the results. After that, p
 of required and recommended fields that can be updated. By default, all required fields are already provided. However,
 you have all the rights to change them. See further details in **User Guide**. 
 """
+
+PREPROCESS = """
+### Preprocessing pipeline
+You will see the file names only if there are files that don't match the existing ones. 
+"""
\ No newline at end of file
